@@ -1,5 +1,5 @@
-const hass = document.querySelector("home-assistant").hass;
-hass.connection.subscribeEvents((event) => {
+const h = document.querySelector("home-assistant").hass;
+h.connection.subscribeEvents((event) => {
   if (
     event.data.domain === "ais_ai_service" &&
     event.data.service === "say_in_browser"
@@ -9,7 +9,7 @@ hass.connection.subscribeEvents((event) => {
     }
     if ("speechSynthesis" in window) {
       window.speechSynthesis.cancel();
-      var speech = new SpeechSynthesisUtterance(event.data.service_data.text);
+      const speech = new SpeechSynthesisUtterance(event.data.service_data.text);
       speech.lang = "pl-PL";
       window.speechSynthesis.speak(speech);
     }
