@@ -39,7 +39,7 @@ function swipeNavigation() {
       ? String(config.skip_tabs)
           .replace(/\s+/g, "")
           .split(",")
-          .map(function(item) {
+          .map(function (item) {
             return parseInt(item, 10);
           })
       : [];
@@ -64,7 +64,7 @@ function swipeNavigation() {
       "HUI-THERMOSTAT-CARD",
       "CH-HEADER",
       "CH-HEADER-BOTTOM",
-      "XIAOMI-VACUUM-MAP-CARD"
+      "XIAOMI-VACUUM-MAP-CARD",
     ];
     if (typeof event.path == "object") {
       for (let element of event.path) {
@@ -111,14 +111,14 @@ function swipeNavigation() {
 
   function filterTabs() {
     if (skip_hidden) {
-      tabs = tabs.filter(element => {
+      tabs = tabs.filter((element) => {
         return (
           !skip_tabs.includes(tabs.indexOf(element)) &&
           getComputedStyle(element, null).display != "none"
         );
       });
     } else {
-      tabs = tabs.filter(element => {
+      tabs = tabs.filter((element) => {
         return !skip_tabs.includes(tabs.indexOf(element));
       });
     }
@@ -140,7 +140,7 @@ function swipeNavigation() {
       view.style.opacity = 0;
       view.style.transform = `translate(${_in}, 0)`;
       view.style.transition = "transform 0.20s, opacity 0.18s";
-      setTimeout(function() {
+      setTimeout(function () {
         tabs[index].dispatchEvent(
           new MouseEvent("click", { bubbles: false, cancelable: true })
         );
@@ -148,7 +148,7 @@ function swipeNavigation() {
         view.style.transform = `translate(${_out}, 0)`;
         view.style.transition = "transform 0s";
       }, 210);
-      setTimeout(function() {
+      setTimeout(function () {
         view.style.transitionDuration = "200ms";
         view.style.opacity = 1;
         view.style.transform = `translate(0px, 0)`;
@@ -158,7 +158,7 @@ function swipeNavigation() {
       view.style.transitionDuration = "200ms";
       view.style.transition = "opacity 0.20s";
       view.style.opacity = 0;
-      setTimeout(function() {
+      setTimeout(function () {
         tabs[index].dispatchEvent(
           new MouseEvent("click", { bubbles: false, cancelable: true })
         );
@@ -166,7 +166,7 @@ function swipeNavigation() {
         view.style.opacity = 0;
         view.style.transition = "opacity 0s";
       }, 210);
-      setTimeout(function() {
+      setTimeout(function () {
         view.style.transitionDuration = "200ms";
         view.style.transition = "opacity 0.20s";
         view.style.opacity = 1;
@@ -176,12 +176,12 @@ function swipeNavigation() {
       view.style.transform = "rotatey(90deg)";
       view.style.transition = "transform 0.20s, opacity 0.20s";
       view.style.opacity = 0.25;
-      setTimeout(function() {
+      setTimeout(function () {
         tabs[index].dispatchEvent(
           new MouseEvent("click", { bubbles: false, cancelable: true })
         );
       }, 210);
-      setTimeout(function() {
+      setTimeout(function () {
         view.style.transitionDuration = "200ms";
         view.style.transform = "rotatey(0deg)";
         view.style.transition = "transform 0.20s, opacity 0.20s";
@@ -195,7 +195,7 @@ function swipeNavigation() {
   }
 }
 
-const callback = mutations => {
+const callback = (mutations) => {
   mutations.forEach(({ addedNodes }) => {
     for (const node of addedNodes) {
       if (node.nodeName == "HA-PANEL-LOVELACE") {
@@ -214,4 +214,4 @@ dashboard_observer.observe(
   { childList: true }
 );
 
-swipeNavigation();
\ No newline at end of file
+swipeNavigation();
